# Changelog

## 0.0.3 (2026-03-19)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/plazafyi/plaza-python/compare/v0.0.2...v0.0.3)

### Bug Fixes

* **deps:** bump minimum typing-extensions version ([50f2f86](https://github.com/plazafyi/plaza-python/commit/50f2f865b2e12b861d1471792556c37b260bf1b7))
* **pydantic:** do not pass `by_alias` unless set ([d76c5de](https://github.com/plazafyi/plaza-python/commit/d76c5ded1f1bc9cb0e17b939f89df78883f83702))


### Chores

* **internal:** tweak CI branches ([2a30d83](https://github.com/plazafyi/plaza-python/commit/2a30d8337e59b5f5ecadb06c88a5387d0a22025c))
* update SDK settings ([ff350db](https://github.com/plazafyi/plaza-python/commit/ff350db5850da19ca56bd5aed82c3ad36df560d2))
* update SDK settings ([3934323](https://github.com/plazafyi/plaza-python/commit/39343235fe15436b087e50c1e089d20e59129521))
* update SDK settings ([540054c](https://github.com/plazafyi/plaza-python/commit/540054c8241d3ac2833bc4dc61ad9cb5db79a50b))
* update SDK settings ([117f361](https://github.com/plazafyi/plaza-python/commit/117f36169b2b0422a201ff20fc767e955d9f22f5))

## 0.0.2 (2026-03-15)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/plazafyi/plaza-python/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([2647344](https://github.com/plazafyi/plaza-python/commit/26473449f53195ac16e2420c9f985176105edbbe))
* configure new SDK language ([eb10f9a](https://github.com/plazafyi/plaza-python/commit/eb10f9a7a2b062bc02d76ce2263eea19121e2c4c))
* update SDK settings ([2fa85be](https://github.com/plazafyi/plaza-python/commit/2fa85be6033f4436eef8b509489403dae170344e))
* update SDK settings ([acff344](https://github.com/plazafyi/plaza-python/commit/acff34420d9a474939b72b495eea1884ea3f0574))
